@@ -7,6 +7,7 @@ import sys
 
 import subprocess
 
+import time
 from whatap import build
 from whatap.util.date_util import DateUtil
 
@@ -129,6 +130,7 @@ def write_file(home, file_name, value):
         f.write(value)
         f.close()
     except Exception as e:
+        print(e)
         print('WHATAP: WHATAP HOME ERROR.')
         print(
             'WHATAP: Try to execute command. \n  {}'.format(
@@ -152,6 +154,8 @@ def init_config(home):
         whatap_home = read_file(home, home.lower())
         if not whatap_home:
             whatap_home = os.getcwd()
+            os.environ[home] = whatap_home
+            
             print('WHATAP: WHATAP_HOME is empty')
             print(
                 'WHATAP: WHATAP_HOME set default CURRENT_WORKING_DIRECTORY value')
@@ -297,6 +301,7 @@ def agent():
         whatap_home = read_file(home, home.lower())
         if not whatap_home:
             whatap_home = os.getcwd()
+            os.environ[home] = whatap_home
             
             print('WHATAP: WHATAP_HOME is empty')
             print(
@@ -328,6 +333,8 @@ def go(batch=False):
     
     os.environ['python.uptime'] = str(DateUtil.datetime())
     os.environ['python.version'] = sys.version
+    os.environ['python.tzname'] = time.tzname[0]
+
     
     os.environ['os.release'] = platform.release()
     
@@ -410,6 +417,7 @@ def go_kill(home, file_name):
 from whatap.trace.mod.application_wsgi import interceptor, start_interceptor, \
     end_interceptor, trace_handler
 
+from whatap.trace.trace_context import TraceContext
 
 def register_app(fn):
     @trace_handler(fn, True)
@@ -434,7 +442,9 @@ def method_profiling(fn):
     def trace(*args, **kwargs):
         callback = None
         try:
-            ctx = start_interceptor(service_name=fn.__name__)
+            ctx = TraceContext()
+            ctx.service_name=fn.__name__
+            ctx = start_interceptor(ctx)
             callback = fn(*args, **kwargs)
             end_interceptor(ctx.thread_id)
         except Exception as e:
@@ -484,8 +494,9 @@ def batch_profiling(fn):
         
         callback = None
         try:
-            ctx = start_interceptor(
-                service_name=module.__file__.split('/').pop())
+            ctx = TraceContext()
+            ctx.service_name=module.__file__.split('/').pop()
+            ctx = start_interceptor(ctx)
             
             callback = fn(*args, **kwargs)
             end_interceptor(ctx.thread_id)
