@@ -7,7 +7,12 @@ Configuration = {
     "trace_user_enabled": True,
     "trace_user_using_ip": True,
     "profile_dbc_close": False,
-
+    
+    "mtid": 0,
+    "httpc_checked": True,
+    "mtrace_rate": 0,
+    "_trace_mtrace_caller_key": "x-wtap-mst",
+    "_trace_mtrace_callee_key": "x-wtap-tx",
 
 
     # "whatap_server_host": "127.0.0.1/127.0.0.1",
